@@ -190,13 +190,15 @@ class PythonExpression:
         return expression(**values)
 
 
-def sliceobj(expression: Union[int, str], **variables) -> slice:
+def sliceobj(expression: Union[int, str, slice], **variables) -> slice:
     """
     Uses `refinery.lib.argformats.PythonExpression` to parse slice expressions
     where the bounds can be given as arithmetic expressions. For example, this
     argument format type will process the string `0x11:0x11+4*0x34` as the slice
     object `slice(17, 225, None)`.
     """
+    if isinstance(expression, slice):
+        return expression
     if isinstance(expression, int):
         sliced = (expression,)
     else:
@@ -605,7 +607,7 @@ class DelayedNumSeqArgument(DelayedArgument):
         except Exception:
             return self._mbin(expression)
 
-    @handler.register('ev')
+    @handler.register('e', 'eval')
     def ev(self, expression: Union[str, ByteString]) -> Iterable[int]:
         """
         Final modifier `ev:expression`; uses a `refinery.lib.argformats.PythonExpression`
@@ -740,7 +742,7 @@ class DelayedRegexpArgument(DelayedArgument):
             return B'.{%s}' % B','.join(t.strip() for t in rng[1:-1].split(B'-'))
 
         pattern = re.split(BR'(\[\s*\d+(?:\s*-\s*\d+)?\s*\])', pattern)
-        pattern[0::2] = [re.sub(BR'[A-F0-9?]{2}', y2r, c) for c in pattern[::2]]
+        pattern[0::2] = [re.sub(BR'[A-Fa-f0-9?]{2}', y2r, c) for c in pattern[::2]]
         pattern[1::2] = [yara_range(b) for b in pattern[1::2]]
         return B''.join(pattern)
 
