@@ -5,7 +5,6 @@ A package containing several sub-packages for various data formats.
 """
 import fnmatch
 import re
-import os
 import collections
 
 from zlib import adler32
@@ -79,6 +78,7 @@ class PathExtractorUnit(Unit, abstract=True):
             '(no effect on regular expressions).') = False,
         **keywords
     ):
+        paths = paths or ['*']
         super().__init__(
             patterns=[
                 PathPattern(p, fuzzy, regex)
@@ -118,12 +118,10 @@ class PathExtractorUnit(Unit, abstract=True):
         raise NotImplementedError
 
     def process(self, data: ByteString) -> ByteString:
-
-        if self.args.join:
-            try:
-                root = data['path']
-            except (KeyError, TypeError):
-                root = ''
+        try:
+            root = data['path']
+        except KeyError:
+            root = ''
 
         results = []
         paths = collections.defaultdict(set)
@@ -135,6 +133,7 @@ class PathExtractorUnit(Unit, abstract=True):
         for p in self.args.patterns:
             for result in results:
                 path = result.path
+                path = '/'.join(path.split('\\'))
                 if not p.check(path):
                     continue
                 if not self.args.list:
@@ -144,8 +143,10 @@ class PathExtractorUnit(Unit, abstract=True):
                             continue
                         self.log_warn('duplicate path with different contents:', path)
                     paths[path].add(csum)
-                if self.args.join:
-                    path = os.path.join(root, path)
+                if self.args.join and root:
+                    if '\\' in root:
+                        root = '/'.join(root.split('\\'))
+                    path = F'{root}/{path}'
                 if self.args.list:
                     yield path.encode(self.codec)
                     continue
