@@ -20,15 +20,17 @@ class peek(HexViewer):
         self,
         lines  : arg('-l', group='SIZE', help='Specify number N of lines in the preview, default is 10.') = 10,
         all    : arg('-a', group='SIZE', help='Output all possible preview lines without restriction') = False,
+        brief  : arg('-b', group='SIZE', help='One line peek, implies --lines=1.') = False,
         decode : arg('-d', group='MODE', help='Attempt to decode and display printable data.') = False,
         esc    : arg('-e', group='MODE', help='Always peek data as string, escape characters if necessary.') = False,
-        brief  : arg('-b', group='MODE', help='One line peek, implies --lines=0.') = False,
-        hexaddr=True, expand=False, width=0
+        hexaddr=True, dense=False, expand=False, width=0
     ):
-        lines = INF if all else lines
+        lines = 1 if brief else INF if all else lines
+        dense = dense or brief
         super(peek, self).__init__(
-            hexaddr=hexaddr, expand=expand, width=width, lines=lines, decode=decode, esc=esc, brief=brief)
-        self.separate = True
+            hexaddr=hexaddr and not brief, expand=expand, width=width, dense=dense, lines=lines, decode=decode, esc=esc, brief=brief)
+        self._sep = True
+        self._idx = None
 
     def process(self, data):
         for line in self._peeklines(data):
@@ -52,12 +54,15 @@ class peek(HexViewer):
                 try:
                     decoded: str = value.decode(self.codec)
                     assert decoded.isprintable()
+                    decoded = F's:{decoded}'
                 except UnicodeDecodeError:
                     decoded = None
                 except AssertionError:
                     decoded = None
-                value = decoded or F'H:{value.hex()}'
-            metavar = F'{name:>{width}} : {value!s}'
+                value = decoded or F'h:{value.hex()}'
+            elif isinstance(value, int):
+                value = F'e:0x{value:X}'
+            metavar = F'{name:>{width}} = {value!s}'
             if len(metavar) > linewidth:
                 metavar = metavar[:linewidth - 3] + '...'
             yield metavar
@@ -78,6 +83,8 @@ class peek(HexViewer):
 
         if magic is not None:
             peeks.append(magic)
+        if self._idx is not None:
+            peeks.insert(0, F'item {self._idx:02d}')
 
         header = ', '.join(peeks)
 
@@ -85,7 +92,7 @@ class peek(HexViewer):
         termsize = get_terminal_size()
         working_codec = None
 
-        if data and not self.args.brief:
+        if data:
             if self.args.decode:
                 for codec in ('UTF8', 'UTF-16LE', 'UTF-16', 'UTF-16BE'):
                     try:
@@ -139,14 +146,20 @@ class peek(HexViewer):
         yield from self._peekmeta(data, width, separator())
 
         if dump:
-            yield separator(F'CODEC={working_codec}' if working_codec else None)
-            yield from dump
+            if not self.args.brief:
+                yield separator(F'CODEC={working_codec}' if working_codec else None)
+                yield from dump
+            else:
+                yield F'data = {next(iter(dump)).strip()}'
 
-        if self.separate:
+        if self._sep:
             yield separator()
 
     def filter(self, inputs):
         from ...lib.tools import lookahead
-        for last, item in lookahead(inputs):
-            self.separate = last
+        for last, (index, item) in lookahead(enumerate(inputs)):
+            self._sep = last
+            if not last or index:
+                self._idx = index
             yield item
+        self._idx = None
